C--------------------------------------------------------------------
C  Copyright (C) 2002,  Space Science and Engineering Center, 
C  University C  of Wisconsin-Madison, Madison WI.
C      
C  This program is free software; you can redistribute it 
C  and/or modify it under the terms of the GNU General 
C  Public License as published by the Free Software Foundation; 
C  either version 2 of the License, or (at your option) any 
C  later version.
C
C  This program is distributed in the hope that it will be 
C  useful, but WITHOUT ANY WARRANTY; without even the implied 
C  warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. 
C  See the  GNU General Public License for more details.
C
C  You should have received a copy of the GNU General Public 
C  License along with this program; if not, write to the Free 
C  Software Foundation, Inc., 59 Temple Place, Suite 330, 
C  Boston, MA  02111-1307 USA
C--------------------------------------------------------------------
C
C
      subroutine db_mod07_file_close( 
     &                                l1b_1km_lun,
     &                                geo_1km_lun,
     &                                mask_lun,
     &                                scan_1km_lun,
     &                                anc_met_lun,
     &                                trc_lun,
     &                                ang_lun,
     &                                bias_lun,
     &                                det_lun,
     &                                mod07_lun,
     &                                hdr_lun
     &                               )
      implicit none
      save

C-----------------------------------------------------------------------
C!F77
C
C!DESCRIPTION:
c Program which will close files used in the DB Atmospheric  
c Profiles software.
C
C!INPUT PARAMETERS:   
C
C   l1b_1km_lun        LUN for open 1km L1B data file
C   geo_1km_lun        LUN for open geo file
C   mask_lun           LUN for open Cloud Mask file
C   scan_1km_lun       LUN for scan based metadata information
C   anc_met_lun        LUN for open met data file
C   trc_lun            LUN for regression coefficient file
C   ang_lun            LUN for view angle file
C   bias_lun           LUN for the ascii bias file
C   det_lun            LUN for the detector list file
C   mod07_lun          LUN for Atmospheric Profiles output file
C   hdr_lun            LUN for Atmospheric Profiles header output file
C   h_output           LUN for debug output text file from include file
C
C!OUTPUT PARAMETERS:   None.
C
C
C!REVISION HISTORY:
c
C!TEAM-UNIQUE HEADER:
C
C!REFERENCES AND CREDITS
C
C EXTERNALS:
C
C       NAMED CONSTANTS:
C
C
C!END-------------------------------------------------------------------

      include 'db_mod07uw_debug.inc'
      include 'hdf.inc'

c --- arguments
      integer l1b_1km_lun, geo_1km_lun, trc_lun, mod07_lun, ang_lun,
     +        scan_1km_lun, anc_met_lun, mask_lun, hdr_lun, bias_lun,
     +        det_lun
c ... local variables
      integer rtn

c ... Hdf external routines
      integer sfend
      external sfend

c ... close files
      close(l1b_1km_lun)
      close(geo_1km_lun)
      close(anc_met_lun)
      close(mask_lun)
      close(scan_1km_lun)
      close(mod07_lun)
      close(hdr_lun)
      close(bias_lun)
      close(det_lun)
c ... HDF close for coefficient file
      rtn = sfend(trc_lun)
      close(ang_lun)
      if (debug .ne. 0) close(h_output)

      return
      end
