C--------------------------------------------------------------------
C  Copyright (C) 2002,  Space Science and Engineering Center, 
C  University C  of Wisconsin-Madison, Madison WI.
C      
C  This program is free software; you can redistribute it 
C  and/or modify it under the terms of the GNU General 
C  Public License as published by the Free Software Foundation; 
C  either version 2 of the License, or (at your option) any 
C  later version.
C
C  This program is distributed in the hope that it will be 
C  useful, but WITHOUT ANY WARRANTY; without even the implied 
C  warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. 
C  See the  GNU General Public License for more details.
C
C  You should have received a copy of the GNU General Public 
C  License along with this program; if not, write to the Free 
C  Software Foundation, Inc., 59 Temple Place, Suite 330, 
C  Boston, MA  02111-1307 USA
C--------------------------------------------------------------------
C
C
      subroutine db_mod07_file_open( 
     &                                filename,
     &                                l1b_1km_neles,
     &                                l1b_1km_lun,
     &                                geo_1km_lun,
     &                                mask_lun,
     &                                scan_1km_lun,
     &                                anc_met_lun,
     &                                trc_lun,
     &                                ang_lun,
     &                                bias_lun,
     &                                det_lun,
     &                                mod07_lun,
     &                                hdr_lun,
     &                                debug_lun
     &                              )
      implicit none
      save

      include 'profiles.inc'
      include 'db_mod07uw_data.inc'
      include 'db_mod07uw_debug.inc'
      include 'hdf.inc'

C-----------------------------------------------------------------------
C!F77
C
C!DESCRIPTION:
c Program which will open files and return unit numbers for 
c all files used in the DB Atmospheric Profiles processing.
C
C!INPUT PARAMETERS:    None.
C
C!OUTPUT PARAMETERS:
C
C   filename           Configuration file name
C   l1b_1km_neles      Number of elements per scan line of data
C   l1b_1km_lun        LUN for open 1km L1B data file
C   geo_1km_lun        LUN for open geo file
C   mask_lun           LUN for open Cloud Mask file
C   scan_1km_lun       LUN for scan based metadata file
C   anc_met_lun        LUN for open met data file
C   trc_lun            LUN for regression coefficient file
C   ang_lun            LUN for view angle file
C   bias_lun           LUN for the ascii bias file
C   det_lun            LUN for the detector list file
C   mod07_lun          LUN for Atmospheric Profiles output file
C   hdr_lun            LUN for Atmospheric Profiles header output file
C
C!REVISION HISTORY:
c
C!TEAM-UNIQUE HEADER:
C
C!REFERENCES AND CREDITS
C
C EXTERNALS:
C
C       NAMED CONSTANTS:
C
C       FUNCTIONS AND SUBROUTINES:
C               hdrgetkeystr.f
c               message.f
C
C!END-------------------------------------------------------------------

c --- constants
      character*18 FUNCTION
      parameter (FUNCTION = 'db_mod07_file_open')

c --- arguments
      integer l1b_1km_neles, l1b_1km_lun, geo_1km_lun, scan_1km_lun, 
     +        anc_met_lun, mask_lun, trc_lun, debug_lun, bias_lun,
     +        mod07_lun, hdr_lun, ang_lun, det_lun
      character*(*) filename

c --- external functions
      integer hdrgetkeystr, sfstart
      external hdrgetkeystr, sfstart

c --- internal variables
      character*12 req
      character*80 keyname
      character*(PATH_MAX) file
      integer len_file, keyindex, status, io_err, level, len
      logical  remove_all

c --- initialize the lun
      l1b_1km_lun  = -1
      geo_1km_lun  = -1
      mask_lun	   = -1
      scan_1km_lun = -1
      anc_met_lun  = -1
      debug_lun	= -1
      hdr_lun	= -1
      mod07_lun = -1
      trc_lun = -1
      ang_lun = -1
      bias_lun = -1
      det_lun = -1

      remove_all = .true.

c --- initialize dummy variables
      req = ' '
      file = ' '


C 1KM Level 1B MODIS DATA FILES

c --- get the file requirement
      keyname = 'L1B_1KM_REQ'
      keyindex = 1
      status = hdrgetkeystr( filename, keyname, keyindex, req )
      if( status.lt.0 ) req = 'OPTIONAL'
      level = 3
      if( req(1:3).eq.'MAN' ) level = 2

c --- get file access information 
      keyname = 'L1B_1KM_NAME'
      keyindex = 1
      status = hdrgetkeystr( filename, keyname, keyindex, file )

c --- check for error reading info file
      if( status.lt.0 ) then 
         call message( 
     &                 FUNCTION,
     &                'FAILED: Read of 1km file info . ',
     &                 0, level 
     &               )

      else
                   
c ------ issue the OPEN request
         OPEN( 
     &         FILE=file,
     &         UNIT=L1B_1KM_UNIT,
     &         FORM=L1B_1KM_FORM,
     &         ACCESS=L1B_1KM_ACCESS,
     &         STATUS=L1B_1KM_STATUS,
     &         RECL=l1b_1km_neles*4,
     &         IOSTAT=io_err, 
     &         ERR=9005
     &       ) 

         call message(
     &                 '--',
     &                'Using 1km L1B file: '// file ,
     &                 0, 4
     &               )

         l1b_1km_lun = L1B_1KM_UNIT
         goto 140

c ------ Failed to open 
9005     continue 
         call message( 
     &                 FUNCTION,
     &                'FAILED: Could not open 1km L1B file. ', 
     &                 0, level 
     &               )

      endif
140   continue
      if( debug.ne.0 ) then
         call strcompress( file, remove_all, len_file )
         write(*,*) '  L1B 1km file: ',file(1:len_file)
      endif
              


C GEOLOCATION FILES: LATITUDE, LONGITUDE, HEIGHT, ...

c --- get the file requirement
      keyname = 'GEO_1KM_REQ'
      keyindex = 1
      status = hdrgetkeystr( filename, keyname, keyindex, req )
      if( status.lt.0 ) req = 'OPTIONAL'
      level = 3
      if( req(1:3).eq.'MAN' ) level = 2

c --- get file access information 
      keyname = 'GEO_1KM_NAME'
      keyindex = 1
      status = hdrgetkeystr( filename, keyname, keyindex, file )

c --- check for error reading info file
      if( status.lt.0 ) then 
         call message( 
     &                 FUNCTION,
     &                'FAILED: Read of Geo file info . ',
     &                 0, level 
     &               )

      else
                   
c ------ issue the OPEN request
         OPEN( 
     &         FILE=file,
     &         UNIT=GEO_1KM_UNIT,
     &         STATUS=GEO_1KM_STATUS,
     &         FORM=GEO_1KM_FORM,
     &         ACCESS=GEO_1KM_ACCESS,
     &         RECL=l1b_1km_neles*4,
     &         IOSTAT=io_err, 
     &         ERR=9006
     &       ) 

         call message(
     &                 '--',
     &                'Using 1km GEO file: '// file ,
     &                 0, 4
     &               )

         geo_1km_lun = GEO_1KM_UNIT
         goto 150

c ------ Failed to open 
9006     continue 
         call message( 
     &                 FUNCTION,
     &                'FAILED: Could not open GEO file. ',
     &                 0, level 
     &               )

      endif
150   continue
      if( debug.ne.0 ) then
         call strcompress( file, remove_all, len_file )
         write(*,*) '  GEO file: ',file(1:len_file)
      endif
              


C SCAN METADATA FILE: TYPE, MIRROR SIDE

c --- get the file requirement
      keyname = 'SCAN_1KM_REQ'
      keyindex = 1
      status = hdrgetkeystr( filename, keyname, keyindex, req )
      if( status.lt.0 ) req = 'OPTIONAL'
      level = 3
      if( req(1:3).eq.'MAN' ) level = 2

c --- get file access information 
      keyname = 'SCAN_1KM_NAME'
      keyindex = 1
      status = hdrgetkeystr( filename, keyname, keyindex, file )

c --- check for error reading info file
      if( status.lt.0 ) then 
         call message( 
     &                 FUNCTION,
     &                'FAILED: Read of Scan Metadata file info . ',
     &                 0, level 
     &               )

      else

c ------ issue the OPEN request
         OPEN( 
     &         FILE=file,
     &         UNIT=SCAN_1KM_UNIT,
     &         STATUS=SCAN_1KM_STATUS,
     &         FORM=SCAN_1KM_FORM,
     &         ACCESS=SCAN_1KM_ACCESS,
     &         RECL=SCAN_1KM_RECL,
     &         IOSTAT=io_err, 
     &         ERR=9007
     &       ) 

         call message(
     &                 '--',
     &                'Using Meta file: '// file ,
     &                 0, 4
     &               )

         scan_1km_lun = SCAN_1KM_UNIT
         goto 160

c ------ Failed to open 
9007     continue 
         call message( 
     &                 FUNCTION,
     &                'FAILED: Could not open Scan Metadata file. ',
     &                 0, level 
     &               )

      endif
160   continue
      if( debug.ne.0 ) then
         call strcompress( file, remove_all, len_file )
         write(*,*) '  Scan Metadata file: ',file(1:len_file)
      endif
      



C ANCILLARY FILES: MET

c --- get the file requirement
      keyname = 'ANC_MET_REQ'
      keyindex = 1
      status = hdrgetkeystr( filename, keyname, keyindex, req )
      if( status.lt.0 ) level=2

c --- get file access information 
      keyname = 'ANC_MET_NAME'
      keyindex = 1
      status = hdrgetkeystr( filename, keyname, keyindex,file )

c --- check for error reading info file
      if( status.lt.0 ) then 
         call message( 
     &                 FUNCTION,
     &                'FAILED: Read of Met Obs file info . ',
     &                 0, level 
     &               )

      else
                   
c ------ issue the OPEN request
         OPEN( 
     &         FILE=file,
     &         UNIT=ANC_MET_UNIT,
     &         STATUS=ANC_MET_STATUS,
     &         FORM=ANC_MET_FORM,
     &         ACCESS=ANC_MET_ACCESS,
     &         RECL=ANC_MET_RECL,
     &         IOSTAT=io_err, 
     &         ERR=9009
     &       ) 

         call message(
     &                 '--',
     &                'Using GDAS Analysis file: '// file ,
     &                 0, 4
     &               )

         anc_met_lun = ANC_MET_UNIT
         goto 180

c ------ Failed to open 
9009     continue 
         call message( 
     &                 FUNCTION,
     &                'FAILED: Could not open GDAS1 file. ',
     &                 0, level 
     &               )

      endif
180   continue
      if( debug.ne.0 ) then
         call strcompress( file, remove_all, len_file )
         write(*,*) '  Met Obs. file: ',file(1:len_file)
      endif
      


C INPUT FILES: CLOUD MASK 

c --- get the file requirement
      keyname = 'MOD35_MASK_REQ'
      keyindex = 1
      status = hdrgetkeystr( filename, keyname, keyindex, req )
      if( status.lt.0 ) req = 'OPTIONAL'
      level = 3
      if( req(1:3).eq.'MAN' ) level = 2

c --- get file access information 
      keyname = 'MOD35_MASK_NAME'
      keyindex = 1
      status = hdrgetkeystr( filename, keyname, keyindex,file )
      call strcompress( file, remove_all, len ) 


c --- check for error reading info file
      if( status.lt.0 ) then 
         call message( 
     &                 FUNCTION,
     &                'FAILED: Read of Cloud Mask file info . ',
     &                 0, level 
     &               )

      else
                   
c ------ issue the OPEN request
         OPEN( 
     &         FILE=file(1:len),
     &         UNIT=MOD35_MASK_UNIT,
     &         STATUS=MOD35_MASK_STATUS,
     &         ACCESS=MOD35_MASK_ACCESS,
     &         RECL=l1b_1km_neles,
     &         IOSTAT=io_err, 
     &         ERR=9010
     &       ) 

         call message(
     &                 '--',
     &                'Using Cloud Mask file: '// file ,
     &                 0, 4
     &               )


         mask_lun = MOD35_MASK_UNIT
         goto 190

c ------ Failed to open 
9010     continue 
         call message( 
     &                 FUNCTION,
     &                'FAILED: Could not open Cloud Mask file. ',
     &                 0, level 
     &               )

      endif
190   continue
      if( debug.ne.0 ) then
         call strcompress( file, remove_all, len_file )
         write(*,*) '  Cloud Mask file: ',file(1:len_file)
      endif

C STATIC INPUT FILES:  REGRESSION COEFFICIENT FILE

c --- get the file requirement
      keyname = 'REG_COEF_REQ'
      keyindex = 1
      status = hdrgetkeystr( filename, keyname, keyindex, req )
      if( status.lt.0 ) level=2

c --- get file access information
      keyname = 'REG_COEF_NAME'
      keyindex = 1
      status = hdrgetkeystr( filename, keyname, keyindex,file )

c --- check for error reading info file
      if( status.lt.0 ) then
         call message(
     &                 FUNCTION,
     &                'FAILED: Read of Reg. Coeff. file info . ',
     &                 0, level
     &               )

      else

c ------ issue the OPEN request - this is an HDF file)
c ...    Open the input HDF file for read only
c ...    (DFACC_READ is defined in hdf.inc)
         trc_lun = sfstart(file, DFACC_READ)
         if (trc_lun .eq. -1) then
            call message(
     &                   FUNCTION,
     &                  'FAILED: Could not open  Coefficient file. ',
     &                   0, level
     &                 )
         endif
         call message(
     &                 '--',
     &                'Using Regression file: '// file ,
     &                 0, 4
     &               )
      endif
      if( debug.ne.0 ) then
         call strcompress( file, remove_all, len_file )
         write(*,*) ' Regression Coefficient file: ',file(1:len_file)
      endif

C STATIC INPUT FILES:  VIEW ANGLE FILE

c --- get the file requirement
      keyname = 'VIEW_ANGLE_REQ'
      keyindex = 1
      status = hdrgetkeystr( filename, keyname, keyindex, req )
      if( status.lt.0 ) level=2

c --- get file access information
      keyname = 'VIEW_ANGLE_NAME'
      keyindex = 1
      status = hdrgetkeystr( filename, keyname, keyindex,file )
      call strcompress( file, remove_all, len ) 

c --- check for error reading info file
      if( status.lt.0 ) then
         call message(
     &                 FUNCTION,
     &                'FAILED: Read of View Angle file info. ',
     &                 0, level
     &               )

      else

c ------ issue the OPEN request
         OPEN(
     &         FILE=file(1:len),
     &         UNIT=VANG_UNIT,
     &         STATUS=VANG_STATUS,
     &         FORM=VANG_FORM,
     &         ACCESS=VANG_ACCESS,
     &         RECL=VANG_RECL,
     &         IOSTAT=io_err,
     &         ERR=9012
     &       )

         call message(
     &                 '--',
     &                'Using View Angle file: '// file ,
     &                 0, 4
     &               )

         ang_lun = VANG_UNIT
         goto 210

c ------ Failed to open
9012     continue
         call message(
     &                 FUNCTION,
     &                'FAILED: Could not open View Angle file. ',
     &                 0, level
     &               )
      endif
210   continue
      if( debug.ne.0 ) then
         call strcompress( file, remove_all, len_file )
         write(*,*) ' View Angle file: ',file(1:len_file)
      endif
      
C STATIC INPUT FILES:  BIAS CORRECTION FILE

c --- get the file requirement
      keyname = 'BIAS_FILE_REQ'
      keyindex = 1
      status = hdrgetkeystr( filename, keyname, keyindex, req )
      if( status.lt.0 ) level=2

c --- get file access information
      keyname = 'BIAS_FILE_NAME'
      keyindex = 1
      status = hdrgetkeystr( filename, keyname, keyindex,file )
      call strcompress( file, remove_all, len ) 

c --- check for error reading info file
      if( status.lt.0 ) then
         call message(
     &                 FUNCTION,
     &                'FAILED: Read of Bias file information ',
     &                 0, level
     &               )

      else

c ------ issue the OPEN request
         OPEN(
     &         FILE=file(1:len),
     &         UNIT=BIAS_UNIT,
     &         STATUS=BIAS_STATUS,
     &         FORM=BIAS_FORM,
     &         ACCESS=BIAS_ACCESS,
     &         IOSTAT=io_err,
     &         ERR=9013
     &       )

         call message(
     &                 '--',
     &                'Using Bias Correction file: '// file ,
     &                 0, 4
     &               )

         bias_lun = BIAS_UNIT
         goto 220

c ------ Failed to open
9013     continue
         call message(
     &                 FUNCTION,
     &                'FAILED: Could not open Bias Correction file. ',
     &                 0, level
     &               )
      endif
220   continue
      if( debug.ne.0 ) then
         call strcompress( file, remove_all, len_file )
         write(*,*) ' Bias Correction file: ',file(1:len_file)
      endif
      
C STATIC INPUT FILES:  DETECTOR USE FILE

c --- get the file requirement
      keyname = 'DET_FILE_REQ'
      keyindex = 1
      status = hdrgetkeystr( filename, keyname, keyindex, req )
      if( status.lt.0 ) level=2

c --- get file access information
      keyname = 'DET_FILE_NAME'
      keyindex = 1
      status = hdrgetkeystr( filename, keyname, keyindex,file )
      call strcompress( file, remove_all, len ) 

c --- check for error reading info file
      if( status.lt.0 ) then
         call message(
     &                 FUNCTION,
     &                'FAILED: Read of Detector Ascii file information',
     &                 0, level
     &               )

      else

c ------ issue the OPEN request
         OPEN(
     &         FILE=file(1:len),
     &         UNIT=DET_UNIT,
     &         STATUS=DET_STATUS,
     &         FORM=DET_FORM,
     &         ACCESS=DET_ACCESS,
     &         IOSTAT=io_err,
     &         ERR=9014
     &       )

         call message(
     &                 '--',
     &                'Using Detector use file: '// file ,
     &                 0, 4
     &               )

         det_lun = DET_UNIT
         goto 230

c ------ Failed to open
9014     continue
         call message(
     &                 FUNCTION,
     &                'FAILED: Could not open ascii Detector file. ',
     &                 0, level
     &               )
      endif
230   continue
      if( debug.ne.0 ) then
         call strcompress( file, remove_all, len_file )
         write(*,*) ' Detector Use file: ',file(1:len_file)
      endif
      
C OUTPUT FILES: ATMOSPHERIC PROFILES

c --- get the file requirement
      keyname = 'MOD07_REQ'
      keyindex = 1
      status = hdrgetkeystr( filename, keyname, keyindex, req )
      if( status.lt.0 ) req = 'OPTIONAL'
      level = 3
      if( req(1:3).eq.'MAN' ) level = 2

c --- get file access information 
      keyname = 'MOD07_NAME'
      keyindex = 1
      status = hdrgetkeystr( filename, keyname, keyindex,file )
      call strcompress( file, remove_all, len ) 


c --- check for error reading info file
      if( status.lt.0 ) then 
         call message( 
     &                 FUNCTION,
     &                'FAILED: Read of Profiles output file info . ',
     &                 0, level 
     &               )

      else
                   
c ------ issue the OPEN request
         OPEN( 
     &         FILE=file(1:len),
     &         UNIT=MOD07_UNIT,
     &         STATUS=MOD07_STATUS,
     &         ACCESS=MOD07_ACCESS,
     &         RECL=( l1b_1km_neles / ISAMP ) * 4,
     &         IOSTAT=io_err, 
     &         ERR=9017
     &       ) 

         call message(
     &                 '--',
     &                'Creating Profiles Output file: '// file ,
     &                 0, 4
     &               )

         mod07_lun = MOD07_UNIT
         goto 260

c ------ Failed to open 
9017     continue 
         call message( 
     &                 FUNCTION,
     &                'FAILED: Could not open output file. ',
     &                 0, level 
     &               )

      endif
260   continue
      if( debug.ne.0 ) then
         call strcompress( file, remove_all, len_file )
         write(*,*) '  Profiles Output file: ',file(1:len_file)
      endif

C OUTPUT FILES: ATMOSPHERIC PROFILES OUTPUT HEADER FILE

c --- get the file requirement
      keyname = 'MOD07_REQ'
      keyindex = 1
      status = hdrgetkeystr( filename, keyname, keyindex, req )
      if( status.lt.0 ) req = 'OPTIONAL'
      level = 3
      if( req(1:3).eq.'MAN' ) level = 2

c --- get file access information 
      keyname = 'MOD07_HDR'
      keyindex = 1
      status = hdrgetkeystr( filename, keyname, keyindex,file )
      call strcompress( file, remove_all, len ) 


c --- check for error reading info file
      if( status.lt.0 ) then 
         call message( 
     &                 FUNCTION,
     &                'FAILED: Read of Profles output header info . ',
     &                 0, level 
     &               )

      else
                   
c ------ issue the OPEN request
         OPEN( 
     &         FILE=file(1:len),
     &         UNIT=MOD07_HDR_UNIT,
     &         STATUS=MOD07_HDR_STATUS,
     &         ACCESS=MOD07_HDR_ACCESS,
     &         IOSTAT=io_err, 
     &         ERR=9018
     &       ) 

         hdr_lun = MOD07_HDR_UNIT
         goto 261

c ------ Failed to open 
9018     continue 
         call message( 
     &                 FUNCTION,
     &                'FAILED: Could not open output header file. ',
     &                 0, level 
     &               )

      endif
261   continue
      if( debug.ne.0 ) then
         call strcompress( file, remove_all, len_file )
         write(*,*) '  Profles Output header file: ',file(1:len_file)
      endif


C RUNTIME DEBUG FILE - Open only if debug flag is not 0

      if (debug .ne. 0) then
c ---   get the file requirement
        keyname = 'DEBUG_REQ'
        keyindex = 1
        status = hdrgetkeystr( filename, keyname, keyindex, req )
        if( status.lt.0 ) req = 'OPTIONAL'
        level = 3
        if( req(1:3).eq.'MAN' ) level = 2

c ---   get file access information 
        keyname = 'DEBUG_NAME'
        keyindex = 1
        status = hdrgetkeystr( filename, keyname, keyindex, file )
        call strcompress( file, remove_all, len ) 

c ---   check for error reading info file
        if( status.lt.0 ) then 
         call message( 
     &                 FUNCTION,
     &                'FAILED: Read of RunTime Debug file info. ',
     &                 0, level 
     &               )

        else
                   
c ------ issue the OPEN request
           OPEN( 
     &           FILE=file(1:len),
     &           UNIT=DEBUG_UNIT,
     &           STATUS=DEBUG_STATUS,
     &           FORM=DEBUG_FORM,
     &           ACCESS=DEBUG_ACCESS,
     &           IOSTAT=io_err, 
     &           ERR=9030 
     &         ) 

           debug_lun = DEBUG_UNIT
           goto 270

c ------   Failed to open 
9030       continue 
           call message( 
     &                 FUNCTION,
     &                'FAILED: Open RunTime Debug file. ',
     &                 0, level 
     &                 )

        endif
270     continue
      endif


      if( debug.ne.0 ) then
         call strcompress( file, remove_all, len_file )
         write(*,*) '  Debug file: ',file(1:len_file)
      endif

      return
      end
