C--------------------------------------------------------------------
C  Copyright (C) 2002,  Space Science and Engineering Center,
C  University C  of Wisconsin-Madison, Madison WI.
C
C  This program is free software; you can redistribute it
C  and/or modify it under the terms of the GNU General
C  Public License as published by the Free Software Foundation;
C  either version 2 of the License, or (at your option) any
C  later version.
C
C  This program is distributed in the hope that it will be
C  useful, but WITHOUT ANY WARRANTY; without even the implied
C  warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
C  See the  GNU General Public License for more details.
C
C  You should have received a copy of the GNU General Public
C  License along with this program; if not, write to the Free
C  Software Foundation, Inc., 59 Temple Place, Suite 330,
C  Boston, MA  02111-1307 USA
C--------------------------------------------------------------------
C
C
      REAL FUNCTION DEWTEM( P, T, W )

C----------------------------------------------------------------------
C !F77
C
C !DESCRIPTION:
C     DETERMINES DEW POINT TEMPERATURE
C
C !INPUT PARAMETERS:
C     P = REFERENCE PRESSURE ( MB )
C     T = REFERENCE TEMPERATURE ( DEG K )
C     W = REFERENCE MIXING RATIO ( G/KG )
C
C !OUTPUT PARAMETERS:
C     DEWTEM = DEW POINT TEMPERATURE ( DEG K )
C
C !REVISION HISTORY:
C
C !TEAM-UNIQUE HEADER:
C    Developed by the MODIS Group, CIMSS/SSEC, UW-Madison.
C
C !DESIGN NOTES:
C
C !END
C-----------------------------------------------------------------------

c ... Scalar Arguments

      REAL P,T,W

c ... Local Scalars

      REAL A,B,CENKEL,CON,EPS,WS,WW,Y

c ... External Functions

      REAL SATMIX
      EXTERNAL SATMIX

c ... Data statements

      DATA EPS,CON,CENKEL/0.621970585,6.1078,273.15/
      DATA A,B/17.2693882,35.86/

      DEWTEM = T
      WS = SATMIX(P,T)
      IF (W.LE.0.0) RETURN
      IF (WS.LE.0.0) RETURN
      IF (W.LT.WS) WW = W/1000.0
      IF (W.GE.WS) WW = WS/1000.0
      Y = ALOG(P/CON*WW/(EPS+WW))/A
      DEWTEM = (CENKEL-B*Y)/(1.0-Y)

      END
