C--------------------------------------------------------------------
C  Copyright (C) 2002,  Space Science and Engineering Center,
C  University C  of Wisconsin-Madison, Madison WI.
C
C  This program is free software; you can redistribute it
C  and/or modify it under the terms of the GNU General
C  Public License as published by the Free Software Foundation;
C  either version 2 of the License, or (at your option) any
C  later version.
C
C  This program is distributed in the hope that it will be
C  useful, but WITHOUT ANY WARRANTY; without even the implied
C  warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
C  See the  GNU General Public License for more details.
C
C  You should have received a copy of the GNU General Public
C  License along with this program; if not, write to the Free
C  Software Foundation, Inc., 59 Temple Place, Suite 330,
C  Boston, MA  02111-1307 USA
C--------------------------------------------------------------------
C
C
      SUBROUTINE MOD07_INITIALIZE_OUTPUT()
      
c-----------------------------------------------------------------------
c !F77
c
c !DESCRIPTION:
c     Initialize output product arrays for MOD07 at 5x5 sampling.
c
c !INPUT PARAMETERS:
c
c !OUTPUT PARAMETERS:
c     The following arrays in COMMON /MOD07_DATA/ are initialized:
c     BRIGHTNESS_TEMP       Brightness temperature
c     RETR_TEMP_PROFILE     Retrieved temperature profile
c     RETR_DEWP_PROFILE     Retrieved dewpoint profile
c     RETR_HITE_PROFILE     Retrieved geopotential height profile
c     SFC_TEMP              Surface temperature
c     SFC_PRES              Surface pressure
c     SFC_ELEV              Surface elevation
c     WATER_VAPOR           Water vapor for entire column, by integrating regression profiles
c     WATER_VAPOR_DIRECT    Water vapor for entire column, by direct regression
c     WATER_VAPOR_LOW       Water vapor for surface to 900 hPa
c     WATER_VAPOR_HIGH      Water vapor for 700 hPa to 300 hPa
c     TOTAL_OZONE           Total column ozone
c     TOTAL_TOTALS          Total totals index
c     LIFTED_INDEX          Lifted index
c     K_INDEX               K index
c
c !REVISION HISTORY:
c    26 February 2002: SWS included Water_Vapor_Direct
c
c !TEAM-UNIQUE HEADER:
c     Developed by the MODIS Group, CIMSS/SSEC, UW-Madison.
c
c !END
c-----------------------------------------------------------------------

      IMPLICIT NONE
          
      INCLUDE 'db_mod07uw_data.inc'
      
c ... local variables

      INTEGER i, j, k

c ... Initialize all the output arrays

      do k = 1, nbands
        do j = 1, max_samp_line
          do i = 1, max_samp_pixel
            brightness_temp( i, j, k ) = bad_value
          end do
        end do
      end do

      do k = 1, outlevels
        do j = 1, max_samp_line
          do i = 1, max_samp_pixel
            retr_temp_profile( i, j, k ) = bad_value
            retr_dewp_profile( i, j, k ) = bad_value
            retr_hite_profile( i, j, k ) = bad_value
          end do
        end do
      end do
            
      do j = 1, max_samp_line
        do i = 1, max_samp_pixel
          sfc_temp( i, j ) = bad_value
          sfc_pres( i, j ) = bad_value
          sfc_elev( i, j ) = bad_value
          water_vapor( i, j ) = bad_value
          water_vapor_direct( i, j ) = bad_value
          water_vapor_low( i, j ) = bad_value
          water_vapor_high( i, j ) = bad_value
          total_ozone( i, j ) = bad_value
          total_totals( i, j ) = bad_value
          lifted_index( i, j ) = bad_value
          k_index( i, j ) = bad_value
        end do
      end do                      

      END
