C--------------------------------------------------------------------
C  Copyright (C) 2002,  Space Science and Engineering Center, 
C  University C  of Wisconsin-Madison, Madison WI.
C      
C  This program is free software; you can redistribute it 
C  and/or modify it under the terms of the GNU General 
C  Public License as published by the Free Software Foundation; 
C  either version 2 of the License, or (at your option) any 
C  later version.
C
C  This program is distributed in the hope that it will be 
C  useful, but WITHOUT ANY WARRANTY; without even the implied 
C  warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. 
C  See the  GNU General Public License for more details.
C
C  You should have received a copy of the GNU General Public 
C  License along with this program; if not, write to the Free 
C  Software Foundation, Inc., 59 Temple Place, Suite 330, 
C  Boston, MA  02111-1307 USA
C--------------------------------------------------------------------
C
C
      SUBROUTINE PRECWV( P, W, NP, U )

C-----------------------------------------------------------------------
C !F77
C
C !DESCRIPTION:
C     Compute precipitable water profile from water vapor mixing ratio
C     profile.
C
C !INPUT PARAMETERS:
C     P           Pressure profile (mb)
C     W           Water vapor mixing ratio profile (g/kg)
C     NP          Number of levels in profile
C
C !OUTPUT PARAMETERS:
C     U           Precipitable water profile (mm)
C
C     Use surface level value U(NP) as total precipitable water vapor
C     amount.
C
C !REVISION HISTORY:
C
C !TEAM-UNIQUE HEADER:
C     Developed by the MODIS Group, CIMSS/SSEC, UW-Madison.
C
C !END
C-----------------------------------------------------------------------

      IMPLICIT NONE
      
c ... Arguments

      REAL p(*), u(*), w(*)
      INTEGER np

c ... Local variables

      REAL dp, f, p1, p2, s, w1, w2
      INTEGER i

c ... Data statements

      data f/1961.33/

      w1 = w(1)
      p1 = p(1)
      s = 0.0
      u(1) = s
      
      do i = 2,np
        w2 = w(i)
        p2 = p(i)
        dp = abs( p2 - p1 )
        s = s + ( w1 + w2 ) * dp / f
        u(i) = s
        w1 = w2
        p1 = p2
      end do

      END
